@@ -142,17 +142,11 @@ SbxBasicFormater::SbxBasicFormater( sal_Unicode _cDecPoint, sal_Unicode _cThousa
 }
 
 // Funktion zur Ausgabe eines Fehler-Textes (zum Debuggen)
-/*
-void SbxBasicFormater::ShowError( char * sErrMsg )
-{
-//	cout << "ERROR in Format$(): " << sErrMsg << endl;
-}
-*/
 // verschiebt alle Zeichen des Strings, angefangen von der nStartPos,
 // um eine Position zu gr"osseren Indizes, d.h. es wird Platz f"ur
 // ein neues (einzuf"ugendes) Zeichen geschafft.
 // ACHTUNG: der String MUSS gross genug sein !
-inline void SbxBasicFormater::ShiftString( String& sStrg, USHORT nStartPos )
+inline void SbxBasicFormater::ShiftString( String& sStrg, sal_uInt16 nStartPos )
 {
     sStrg.Erase( nStartPos,1 );
 }
@@ -175,7 +169,7 @@ void SbxBasicFormater::AppendDigit( String& sStrg, short nDigit )
 // verschiebt den Dezimal-Punkt um eine Stelle nach links
 void SbxBasicFormater::LeftShiftDecimalPoint( String& sStrg )
 {
-    USHORT nPos = sStrg.Search( cDecPoint );
+    sal_uInt16 nPos = sStrg.Search( cDecPoint );
 
     if( nPos!=STRING_NOTFOUND )
     {
@@ -189,13 +183,13 @@ void SbxBasicFormater::LeftShiftDecimalPoint( String& sStrg )
 // es wird ein Flag zur"uckgeliefert, falls ein Overflow auftrat,
 // d.h. 99.99 --> 100.00, d.h. ein Gr"ossenordung ge"andert wurde
 // (geschieht beim Runden einer 9).
-void SbxBasicFormater::StrRoundDigit( String& sStrg, short nPos, BOOL& bOverflow )
+void SbxBasicFormater::StrRoundDigit( String& sStrg, short nPos, sal_Bool& bOverflow )
 {
     // wurde ggf ein falscher Index uebergeben --> Aufruf ignorieren
     if( nPos<0 )
         return;
 
-    bOverflow = FALSE;
+    bOverflow = sal_False;
     // "uberspringe den Dezimalpunkt und Tausender-Trennzeichen
     sal_Unicode c = sStrg.GetChar( nPos );
     if( nPos>0 && (c == cDecPoint || c == cThousandSep) )
@@ -219,7 +213,7 @@ void SbxBasicFormater::StrRoundDigit( String& sStrg, short nPos, BOOL& bOverflow
         ShiftString( sStrg,0 );
         // f"uhrende 1 einf"ugen: z.B. 99.99 f"ur 0.0
         sStrg.SetChar( 0, '1' );
-        bOverflow = TRUE;
+        bOverflow = sal_True;
     }
     else
     {
@@ -244,7 +238,7 @@ void SbxBasicFormater::StrRoundDigit( String& sStrg, short nPos, BOOL& bOverflow
             ShiftString( sStrg,nPos+1 );
             // f"uhrende 1 einf"ugen
             sStrg.SetChar( nPos+1, '1' );
-            bOverflow = TRUE;
+            bOverflow = sal_True;
         }
     }
 }
@@ -252,7 +246,7 @@ void SbxBasicFormater::StrRoundDigit( String& sStrg, short nPos, BOOL& bOverflow
 // rundet in einem String die Ziffer an der angegebenen Stelle
 void SbxBasicFormater::StrRoundDigit( String& sStrg, short nPos )
 {
-    BOOL bOverflow;
+    sal_Bool bOverflow;
 
     StrRoundDigit( sStrg,nPos,bOverflow );
 }
@@ -303,7 +297,7 @@ void SbxBasicFormater::InitExp( double _dNewExp )
 
 // bestimmt die Ziffer an der angegebenen Stelle (gedacht zur Anwendung im
 // Scan-Durchlauf)
-short SbxBasicFormater::GetDigitAtPosScan( short nPos, BOOL& bFoundFirstDigit )
+short SbxBasicFormater::GetDigitAtPosScan( short nPos, sal_Bool& bFoundFirstDigit )
 {
     // Versuch eine gr"ossere Ziffer zu lesen,
     // z.B. Stelle 4 in 1.234,
@@ -313,18 +307,18 @@ short SbxBasicFormater::GetDigitAtPosScan( short nPos, BOOL& bFoundFirstDigit )
         return _NO_DIGIT;
     // bestimme den Index der Stelle in dem Number-String:
     // "uberlese das Vorzeichen
-    USHORT no = 1;
+    sal_uInt16 no = 1;
     // falls notwendig den Dezimal-Punkt "uberlesen:
     if( nPos<nNumExp )
         no++;
     no += nNumExp-nPos;
     // Abfrage der ersten (g"ultigen) Ziffer der Zahl --> Flag setzen
     if( nPos==nNumExp )
-        bFoundFirstDigit = TRUE;
+        bFoundFirstDigit = sal_True;
     return (short)(sSciNumStrg.GetChar( no ) - ASCII_0);
 }
 
-short SbxBasicFormater::GetDigitAtPosExpScan( short nPos, BOOL& bFoundFirstDigit )
+short SbxBasicFormater::GetDigitAtPosExpScan( short nPos, sal_Bool& bFoundFirstDigit )
 {
     // ist die abgefragte Stelle zu gross f"ur den Exponenten ?
     if( nPos>nExpExp )
@@ -332,11 +326,11 @@ short SbxBasicFormater::GetDigitAtPosExpScan( short nPos, BOOL& bFoundFirstDigit
 
     // bestimme den Index der Stelle in dem Number-String:
     // "uberlese das Vorzeichen
-    USHORT no = 1;
+    sal_uInt16 no = 1;
     no += nExpExp-nPos;
     // Abfrage der ersten (g"ultigen) Ziffer der Zahl --> Flag setzen
     if( nPos==nExpExp )
-        bFoundFirstDigit = TRUE;
+        bFoundFirstDigit = sal_True;
     return (short)(sNumExpStrg.GetChar( no ) - ASCII_0);
 }
 
@@ -344,7 +338,7 @@ short SbxBasicFormater::GetDigitAtPosExpScan( short nPos, BOOL& bFoundFirstDigit
 // Zahl ggf. NICHT normiert (z.B. 1.2345e-03) dargestellt werden soll,
 // sondern eventuell 123.345e-3 !
 short SbxBasicFormater::GetDigitAtPosExpScan( double dNewExponent, short nPos,
-                                              BOOL& bFoundFirstDigit )
+                                              sal_Bool& bFoundFirstDigit )
 {
     // neuer Exponent wurde "ubergeben, aktualisiere
     // die tempor"aren Klassen-Variablen
@@ -379,19 +373,16 @@ TODO: ggf einen 'intelligenten' Peek-Parser um Rundungsfehler bei
 // In bFoundFirstDigit wird ggf. ein Flag gesetzt wenn eine Ziffer
 // gefunden wurde, dies wird dazu verwendet um 'Fehler' beim Parsen 202
 // zu vermeiden, die
-//
 // ACHTUNG: anscheinend gibt es manchmal noch Probleme mit Rundungs-Fehlern!
 short SbxBasicFormater::GetDigitAtPos( double dNumber, short nPos,
-                                double& dNextNumber, BOOL& bFoundFirstDigit )
+                                double& dNextNumber, sal_Bool& bFoundFirstDigit )
 // ACHTUNG: nPos kann auch negativ werden, f"ur Stellen nach dem Dezimal-Punkt
 {
-    double dTemp = dNumber;
-    double dDigit,dPos;
+    double dDigit;
     short  nMaxDigit;
 
     // erst mal aus der Zahl eine positive Zahl machen:
     dNumber = fabs( dNumber );
-    dPos = (double)nPos;
 
     // "uberpr"ufe ob Zahl zu klein f"ur angegebene Stelle ist
     nMaxDigit = (short)get_number_of_digits( dNumber );
@@ -401,7 +392,7 @@ short SbxBasicFormater::GetDigitAtPos( double dNumber, short nPos,
     if( nMaxDigit<nPos && !bFoundFirstDigit && nPos>=0 )
         return _NO_DIGIT;
     // Ziffer gefunden, setze Flag:
-    bFoundFirstDigit = TRUE;
+    bFoundFirstDigit = sal_True;
     for( short i=nMaxDigit; i>=nPos; i-- )
     {
         double dI = (double)i;
@@ -433,14 +424,14 @@ short SbxBasicFormater::RoundDigit( double dNumber )
 // und liefert diesen zur"uck.
 // Somit wird ein neuer String erzeugt, der vom Aufrufer wieder freigegeben
 // werden muss
-String SbxBasicFormater::GetPosFormatString( const String& sFormatStrg, BOOL & bFound )
+String SbxBasicFormater::GetPosFormatString( const String& sFormatStrg, sal_Bool & bFound )
 {
-    bFound = FALSE;		// default...
-    USHORT nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
+    bFound = sal_False;		// default...
+    sal_uInt16 nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
 
     if( nPos!=STRING_NOTFOUND )
     {
-        bFound = TRUE;
+        bFound = sal_True;
         // der Format-String f"ur die positiven Zahlen ist alles
         // vor dem ersten ';'
         return sFormatStrg.Copy( 0,nPos );
@@ -452,10 +443,10 @@ String SbxBasicFormater::GetPosFormatString( const String& sFormatStrg, BOOL & b
 }
 
 // siehe auch GetPosFormatString()
-String SbxBasicFormater::GetNegFormatString( const String& sFormatStrg, BOOL & bFound )
+String SbxBasicFormater::GetNegFormatString( const String& sFormatStrg, sal_Bool & bFound )
 {
-    bFound = FALSE;		// default...
-    USHORT nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
+    bFound = sal_False;		// default...
+    sal_uInt16 nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
 
     if( nPos!=STRING_NOTFOUND )
     {
@@ -465,7 +456,7 @@ String SbxBasicFormater::GetNegFormatString( const String& sFormatStrg, BOOL & b
         String sTempStrg = sFormatStrg.Copy( nPos+1 );
         // und suche darin ggf. ein weiteres ';'
         nPos = sTempStrg.Search( FORMAT_SEPARATOR );
-        bFound = TRUE;
+        bFound = sal_True;
         if( nPos==STRING_NOTFOUND )
             // keins gefunden, liefere alles...
             return sTempStrg;
@@ -479,10 +470,10 @@ String SbxBasicFormater::GetNegFormatString( const String& sFormatStrg, BOOL & b
 }
 
 // siehe auch GetPosFormatString()
-String SbxBasicFormater::Get0FormatString( const String& sFormatStrg, BOOL & bFound )
+String SbxBasicFormater::Get0FormatString( const String& sFormatStrg, sal_Bool & bFound )
 {
-    bFound = FALSE;		// default...
-    USHORT nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
+    bFound = sal_False;		// default...
+    sal_uInt16 nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
 
     if( nPos!=STRING_NOTFOUND )
     {
@@ -494,7 +485,7 @@ String SbxBasicFormater::Get0FormatString( const String& sFormatStrg, BOOL & bFo
         nPos = sTempStrg.Search( FORMAT_SEPARATOR );
         if( nPos!=STRING_NOTFOUND )
         {
-            bFound = TRUE;
+            bFound = sal_True;
             sTempStrg = sTempStrg.Copy( nPos+1 );
             nPos = sTempStrg.Search( FORMAT_SEPARATOR );
             if( nPos==STRING_NOTFOUND )
@@ -511,10 +502,10 @@ String SbxBasicFormater::Get0FormatString( const String& sFormatStrg, BOOL & bFo
 }
 
 // siehe auch GetPosFormatString()
-String SbxBasicFormater::GetNullFormatString( const String& sFormatStrg, BOOL & bFound )
+String SbxBasicFormater::GetNullFormatString( const String& sFormatStrg, sal_Bool & bFound )
 {
-    bFound = FALSE;		// default...
-    USHORT nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
+    bFound = sal_False;		// default...
+    sal_uInt16 nPos = sFormatStrg.Search( FORMAT_SEPARATOR );
 
     if( nPos!=STRING_NOTFOUND )
     {
@@ -531,7 +522,7 @@ String SbxBasicFormater::GetNullFormatString( const String& sFormatStrg, BOOL &
             nPos = sTempStrg.Search( FORMAT_SEPARATOR );
             if( nPos!=STRING_NOTFOUND )
             {
-                bFound = TRUE;
+                bFound = sal_True;
                 return sTempStrg.Copy( nPos+1 );
             }
         }
@@ -548,11 +539,11 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
                 short& nNoOfDigitsLeft, short& nNoOfDigitsRight,
                 short& nNoOfOptionalDigitsLeft,
                 short& nNoOfExponentDigits, short& nNoOfOptionalExponentDigits,
-                BOOL& bPercent, BOOL& bCurrency, BOOL& bScientific,
-                BOOL& bGenerateThousandSeparator,
+                sal_Bool& bPercent, sal_Bool& bCurrency, sal_Bool& bScientific,
+                sal_Bool& bGenerateThousandSeparator,
                 short& nMultipleThousandSeparators )
 {
-    USHORT nLen;
+    sal_uInt16 nLen;
     short nState = 0;
 
     nLen = sFormatStrg.Len();
@@ -562,9 +553,9 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
     nNoOfOptionalDigitsLeft = 0;
     nNoOfExponentDigits = 0;
     nNoOfOptionalExponentDigits = 0;
-    bPercent = FALSE;
-    bCurrency = FALSE;
-    bScientific = FALSE;
+    bPercent = sal_False;
+    bCurrency = sal_False;
+    bScientific = sal_False;
     // ab 11.7.97: sobald ein Komma in dem Format String gefunden wird,
     // werden alle 3 Zehnerpotenzen markiert (d.h. tausender, milionen, ...)
     // bisher wurde nur an den gesetzten Position ein Tausender-Separator
@@ -573,7 +564,7 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
     bGenerateThousandSeparator = sFormatStrg.Search( ',' ) != STRING_NOTFOUND;
     nMultipleThousandSeparators = 0;
     // und untersuche den Format-String nach den gew"unschten Informationen
-    for( USHORT i=0; i<nLen; i++ )
+    for( sal_uInt16 i=0; i<nLen; i++ )
     {
         sal_Unicode c = sFormatStrg.GetChar( i );
         switch( c ) {
@@ -616,15 +607,10 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
                     return -1;	// ERROR: zu viele Dezimal-Punkte
                 break;
             case '%':
-                bPercent = TRUE;
-                /* old:
-                bPercent++;
-                if( bPercent>1 )
-                    return -2;	// ERROR: zu viele Prozent-Zeichen
-                */
+                bPercent = sal_True;
                 break;
             case '(':
-                bCurrency = TRUE;
+                bCurrency = sal_True;
                 break;
             case ',':
             {
@@ -640,13 +626,8 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
                 if( nNoOfDigitsLeft > 0 || nNoOfDigitsRight > 0 )
                 {
                      nState = -1;	// breche jetzt das Z"ahlen der Stellen ab
-                    bScientific = TRUE;
+                    bScientific = sal_True;
                 }
-                /* old:
-                bScientific++;
-                if( bScientific>1 )
-                    return -3;	// ERROR: zu viele Exponent-Zeichen
-                */
                 break;
             // EIGENES Kommando-Zeichen, das die Erzeugung der
             // Tausender-Trennzeichen einschaltet
@@ -655,7 +636,7 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
                 i++;
                 break;
             case CREATE_1000SEP_CHAR:
-                bGenerateThousandSeparator = TRUE;
+                bGenerateThousandSeparator = sal_True;
                 break;
         }
     }
@@ -666,12 +647,12 @@ short SbxBasicFormater::AnalyseFormatString( const String& sFormatStrg,
 // erzeugt werden soll
 void SbxBasicFormater::ScanFormatString( double dNumber,
                                 const String& sFormatStrg, String& sReturnStrg,
-                                BOOL bCreateSign )
+                                sal_Bool bCreateSign )
 {
     short 	/*nErr,*/nNoOfDigitsLeft,nNoOfDigitsRight,nNoOfOptionalDigitsLeft,
             nNoOfExponentDigits,nNoOfOptionalExponentDigits,
             nMultipleThousandSeparators;
-    BOOL 	bPercent,bCurrency,bScientific,bGenerateThousandSeparator;
+    sal_Bool 	bPercent,bCurrency,bScientific,bGenerateThousandSeparator;
 
     // Initialisiere den Return-String
     sReturnStrg = String();
@@ -693,23 +674,11 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
             - sonstige Fehler ? mehrfache Dezimalpunkte, E's, etc.
         --> Fehler werden zur Zeit einfach ignoriert
     */
-    /*nErr =*/ AnalyseFormatString( sFormatStrg,nNoOfDigitsLeft,nNoOfDigitsRight,
+    AnalyseFormatString( sFormatStrg,nNoOfDigitsLeft,nNoOfDigitsRight,
                     nNoOfOptionalDigitsLeft,nNoOfExponentDigits,
                     nNoOfOptionalExponentDigits,
                     bPercent,bCurrency,bScientific,bGenerateThousandSeparator,
                     nMultipleThousandSeparators );
-    /* es werden alle Fehler ignoriert, wie in Visual-Basic
-    if( nErr!=0 )
-    {
-        char sBuffer[512];
-
-        //sprintf( sBuffer,"bad format-string >%s< err=%i",sFormatStrg,nErr );
-        strcpy( sBuffer,"bad format-string" );
-        ShowError( sBuffer );
-    }
-    else
-    */
-    {
         // Spezialbehandlung f"ur Spezialzeichen
         if( bPercent )
             dNumber *= 100.0;
@@ -722,12 +691,12 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
         double dExponent;
         short i,nLen;
         short nState,nDigitPos,nExponentPos,nMaxDigit,nMaxExponentDigit;
-        BOOL bFirstDigit,bFirstExponentDigit,bFoundFirstDigit,
+        sal_Bool bFirstDigit,bFirstExponentDigit,bFoundFirstDigit,
              bIsNegative,bZeroSpaceOn, bSignHappend,bDigitPosNegative;
 
         // Initialisierung der Arbeits-Variablen
-        bSignHappend = FALSE;
-        bFoundFirstDigit = FALSE;
+        bSignHappend = sal_False;
+        bFoundFirstDigit = sal_False;
         bIsNegative = dNumber<0.0;
         nLen = sFormatStrg.Len();
         dExponent = get_number_of_digits( dNumber );
@@ -737,8 +706,6 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
         bDigitPosNegative = false;
         if( bScientific )
         {
-            //if( nNoOfOptionalDigitsLeft>0 )
-            //	ShowError( "# in scientific-format in front of the decimal-point has no effect" );
             // beim Exponent ggf. "uberz"ahlige Stellen vor dem Komma abziehen
             dExponent = dExponent - (double)(nNoOfDigitsLeft-1);
             nDigitPos = nMaxDigit;
@@ -751,8 +718,8 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
             // hier ben"otigt man keine Exponent-Daten !
             bDigitPosNegative = (nDigitPos < 0);
         }
-        bFirstDigit = TRUE;
-        bFirstExponentDigit = TRUE;
+        bFirstDigit = sal_True;
+        bFirstExponentDigit = sal_True;
         nState = 0; // 0 --> Mantisse; 1 --> Exponent
         bZeroSpaceOn = 0;
 
@@ -782,14 +749,13 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                     // Behandlung der Mantisse
                         if( bFirstDigit )
                         {
-                            //org:bFirstDigit = FALSE;
                             // ggf. Vorzeichen erzeugen
                             // Bem.: bei bCurrency soll das negative
                             //       Vorzeichen durch () angezeigt werden
-                            if( bIsNegative && !bCreateSign/*!bCurrency*/ && !bSignHappend )
+                            if( bIsNegative && !bCreateSign && !bSignHappend )
                             {
                                 // nur einmal ein Vorzeichen ausgeben
-                                bSignHappend = TRUE;
+                                bSignHappend = sal_True;
                                 StrAppendChar( sReturnStrg,'-' );
                             }
                             // hier jetzt "uberz"ahlige Stellen ausgeben,
@@ -807,7 +773,7 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                                     // wurde wirklich eine Ziffer eingefuegt ?
                                     if( nTempDigit!=_NO_DIGIT )
                                         // jetzt wurde wirklich eine Ziffer ausgegeben, Flag setzen
-                                        bFirstDigit = FALSE;
+                                        bFirstDigit = sal_False;
                                     // muss ggf. ein Tausender-Trennzeichen erzeugt werden?
                                     if( bGenerateThousandSeparator && ( c=='0' || nMaxDigit>=nDigitPos ) && j>0 && (j % 3 == 0) )
                                         StrAppendChar( sReturnStrg,cThousandSep );
@@ -819,7 +785,7 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                         {
                             AppendDigit( sReturnStrg,0 );		// Ja
                             // jetzt wurde wirklich eine Ziffer ausgegeben, Flag setzen
-                            bFirstDigit = FALSE;
+                            bFirstDigit = sal_False;
                             bZeroSpaceOn = 1;
                             // BEM.: bei Visual-Basic schaltet die erste 0 f"ur alle
                             //       nachfolgenden # (bis zum Dezimal-Punkt) die 0 ein,
@@ -839,7 +805,7 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                             // wurde wirklich eine Ziffer eingefuegt ?
                             if( nTempDigit!=_NO_DIGIT )
                                 // jetzt wurde wirklich eine Ziffer ausgegeben, Flag setzen
-                                bFirstDigit = FALSE;
+                                bFirstDigit = sal_False;
                             // muss ggf. ein Tausender-Trennzeichen erzeugt werden?
                             if( bGenerateThousandSeparator && ( c=='0' || nMaxDigit>=nDigitPos ) && nDigitPos>0 && (nDigitPos % 3 == 0) )
                                 StrAppendChar( sReturnStrg,cThousandSep );
@@ -853,7 +819,7 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                         if( bFirstExponentDigit )
                         {
                             // Vorzeichen wurde schon bei e/E ausgegeben
-                            bFirstExponentDigit = FALSE;
+                            bFirstExponentDigit = sal_False;
                             if( nMaxExponentDigit>nExponentPos )
                             // hier jetzt "uberz"ahlige Stellen ausgeben,
                             // d.h. vom Format-String nicht erfasste Stellen
@@ -914,7 +880,7 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                             break;
                         }
 
-                        BOOL bOverflow = FALSE;
+                        sal_Bool bOverflow = sal_False;
 #ifdef _with_sprintf
                         short nNextDigit = GetDigitAtPosScan( nDigitPos,bFoundFirstDigit );
 #else
@@ -960,19 +926,9 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                             else
                                 StrAppendChar( sReturnStrg,'+' );
                         }
-                        //else
-                        //	ShowError( "operator e/E did not find + or -" );
                     }
-                    //else
-                    //	ShowError( "operator e/E ended with 0" );
                     break;
                 case ',':
-                    // ACHTUNG: nur falls Zahl bisher ausgegeben wurde
-                    //			das Zeichen ausgeben
-                    ////--> Siehe Kommentar vom 11.7. in AnalyseFormatString()
-                    ////if( !bFirstDigit )
-                    ////	// gebe Tausender-Trennzeichen aus
-                    ////	StrAppendChar( sReturnStrg,cThousandSep );
                     break;
                 case ';':
                     break;
@@ -1002,12 +958,9 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                     ParseBack( sReturnStrg,sFormatStrg,i-1 );
                     // Sonderzeichen gefunden, gebe N"ACHSTES
                     // Zeichen direkt aus (falls es existiert)
-                    // i++;
                     c = sFormatStrg.GetChar( ++i );
                     if( c!=0 )
                         StrAppendChar( sReturnStrg,c );
-                    //else
-                    //	ShowError( "operator \\ ended with 0" );
                     break;
                 case CREATE_1000SEP_CHAR:
                     // hier ignorieren, Aktion wurde schon in
@@ -1019,9 +972,6 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
                         ( c>='A' && c<='Z' ) ||
                         ( c>='1' && c<='9' ) )
                         StrAppendChar( sReturnStrg,c );
-                    // else
-                        // ignorieren !
-                    // ehemals: ShowError( "bad character in format-string" );
             }
         }
         // Format-String wurde vollst"andig gescanned,
@@ -1043,12 +993,11 @@ void SbxBasicFormater::ScanFormatString( double dNumber,
         // ABER nur Stellen nach dem Dezimal-Punkt k"onnen gel"oscht werden
         if( nNoOfDigitsRight>0 )
             ParseBack( sReturnStrg,sFormatStrg,sFormatStrg.Len()-1 );
-    }
 }
 
 String SbxBasicFormater::BasicFormatNull( String sFormatStrg )
 {
-    BOOL bNullFormatFound;
+    sal_Bool bNullFormatFound;
     String sNullFormatStrg = GetNullFormatString( sFormatStrg,bNullFormatFound );
 
     if( bNullFormatFound )
@@ -1060,7 +1009,7 @@ String SbxBasicFormater::BasicFormatNull( String sFormatStrg )
 
 String SbxBasicFormater::BasicFormat( double dNumber, String sFormatStrg )
 {
-    BOOL bPosFormatFound,bNegFormatFound,b0FormatFound;
+    sal_Bool bPosFormatFound,bNegFormatFound,b0FormatFound;
 
     // analysiere Format-String auf vordefinierte Formate:
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_GENERALNUMBER ) )
@@ -1087,7 +1036,6 @@ String SbxBasicFormater::BasicFormat( double dNumber, String sFormatStrg )
     String sPosFormatStrg = GetPosFormatString( sFormatStrg, bPosFormatFound );
     String sNegFormatStrg = GetNegFormatString( sFormatStrg, bNegFormatFound );
     String s0FormatStrg = Get0FormatString( sFormatStrg, b0FormatFound );
-    //String sNullFormatStrg = GetNullFormatString( sFormatStrg, bNullFormatFound );
 
     String sReturnStrg;
     String sTempStrg;
@@ -1109,7 +1057,7 @@ String SbxBasicFormater::BasicFormat( double dNumber, String sFormatStrg )
             // verwende String fuer positive Werte
             sTempStrg = sPosFormatStrg;
         }
-        ScanFormatString( dNumber, sTempStrg, sReturnStrg,/*bCreateSign=*/FALSE );
+        ScanFormatString( dNumber, sTempStrg, sReturnStrg,/*bCreateSign=*/sal_False );
     }
     else
     {
@@ -1138,33 +1086,33 @@ String SbxBasicFormater::BasicFormat( double dNumber, String sFormatStrg )
         {
             ScanFormatString( dNumber,
                     (/*sPosFormatStrg!=EMPTYFORMATSTRING*/bPosFormatFound ? sPosFormatStrg : sFormatStrg),
-                    sReturnStrg,/*bCreateSign=*/FALSE );
+                    sReturnStrg,/*bCreateSign=*/sal_False );
         }
     }
     return sReturnStrg;
 }
 
-BOOL SbxBasicFormater::isBasicFormat( String sFormatStrg )
+sal_Bool SbxBasicFormater::isBasicFormat( String sFormatStrg )
 {
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_GENERALNUMBER ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_CURRENCY ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_FIXED ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_STANDARD ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_PERCENT ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_SCIENTIFIC ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_YESNO ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_TRUEFALSE ) )
-        return TRUE;
+        return sal_True;
     if( sFormatStrg.EqualsIgnoreCaseAscii( BASICFORMAT_ONOFF ) )
-        return TRUE;
-    return FALSE;
+        return sal_True;
+    return sal_False;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
