@@ -46,7 +46,8 @@
 #include <osl/diagnose.h>
 
 #include <algorithm>
-#include <functional>
+
+#include <o3tl/compat_functional.hxx>
 
 namespace drivermanager
 {
@@ -59,7 +60,7 @@ using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::logging;
 using namespace ::osl;
 
-#define SERVICE_SDBC_DRIVER		::rtl::OUString::createFromAscii("com.sun.star.sdbc.Driver")
+#define SERVICE_SDBC_DRIVER		::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sdbc.Driver"))
 
 void throwNoSuchElementException() throw(NoSuchElementException)
 {
@@ -118,8 +119,6 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
     //=====================================================================
     //= helper
     //=====================================================================
-    //---------------------------------------------------------------------
-    //--- 24.08.01 11:27:59 -----------------------------------------------
 
     /// an STL functor which ensures that a SdbcDriver described by a DriverAccess is loaded
     struct EnsureDriver : public ::std::unary_function< DriverAccess, DriverAccess >
@@ -135,9 +134,6 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
         }
     };
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 11:28:04 -----------------------------------------------
-
     /// an STL functor which extracts a SdbcDriver from a DriverAccess
     struct ExtractDriverFromAccess : public ::std::unary_function< DriverAccess, SdbcDriver >
     {
@@ -147,19 +143,13 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
         }
     };
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 12:37:50 -----------------------------------------------
-
-    typedef ::std::unary_compose< ExtractDriverFromAccess, EnsureDriver > ExtractAfterLoad_BASE;
+    typedef ::o3tl::unary_compose< ExtractDriverFromAccess, EnsureDriver > ExtractAfterLoad_BASE;
     /// an STL functor which loads a driver described by a DriverAccess, and extracts the SdbcDriver
     struct ExtractAfterLoad : public ExtractAfterLoad_BASE
     {
         ExtractAfterLoad() : ExtractAfterLoad_BASE( ExtractDriverFromAccess(), EnsureDriver() ) { }
     };
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 11:42:36 -----------------------------------------------
-
     struct ExtractDriverFromCollectionElement : public ::std::unary_function< DriverCollection::value_type, SdbcDriver >
     {
         SdbcDriver operator()( const DriverCollection::value_type& _rElement ) const
@@ -168,9 +158,6 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
         }
     };
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 11:51:03 -----------------------------------------------
-
     // predicate for checking whether or not a driver accepts a given URL
     class AcceptsURL : public ::std::unary_function< SdbcDriver, bool >
     {
@@ -193,25 +180,17 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
         }
     };
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 12:51:54 -----------------------------------------------
-
     static sal_Int32 lcl_getDriverPrecedence( const ::comphelper::ComponentContext& _rContext, Sequence< ::rtl::OUString >& _rPrecedence )
     {
         _rPrecedence.realloc( 0 );
         try
         {
             // some strings we need
-            const ::rtl::OUString sConfigurationProviderServiceName =
-                ::rtl::OUString::createFromAscii("com.sun.star.configuration.ConfigurationProvider");
-            const ::rtl::OUString sDriverManagerConfigLocation =
-                ::rtl::OUString::createFromAscii("org.openoffice.Office.DataAccess/DriverManager");
-            const ::rtl::OUString sDriverPreferenceLocation =
-                ::rtl::OUString::createFromAscii("DriverPrecedence");
-            const ::rtl::OUString sNodePathArgumentName =
-                ::rtl::OUString::createFromAscii("nodepath");
-            const ::rtl::OUString sNodeAccessServiceName =
-                ::rtl::OUString::createFromAscii("com.sun.star.configuration.ConfigurationAccess");
+            const ::rtl::OUString sConfigurationProviderServiceName( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationProvider" ));
+            const ::rtl::OUString sDriverManagerConfigLocation( RTL_CONSTASCII_USTRINGPARAM( "org.openoffice.Office.DataAccess/DriverManager" ));
+            const ::rtl::OUString sDriverPreferenceLocation( RTL_CONSTASCII_USTRINGPARAM( "DriverPrecedence" ));
+            const ::rtl::OUString sNodePathArgumentName( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ));
+            const ::rtl::OUString sNodeAccessServiceName( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationAccess" ));
 
             // create a configuration provider
             Reference< XMultiServiceFactory > xConfigurationProvider;
@@ -245,9 +224,6 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
         return _rPrecedence.getLength();
     }
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 13:01:56 -----------------------------------------------
-
     /// an STL argorithm compatible predicate comparing two DriverAccess instances by their implementation names
     struct CompareDriverAccessByName : public ::std::binary_function< DriverAccess, DriverAccess, bool >
     {
@@ -258,9 +234,6 @@ Any SAL_CALL ODriverEnumeration::nextElement(  ) throw(NoSuchElementException, W
         }
     };
 
-    //---------------------------------------------------------------------
-    //--- 24.08.01 13:08:17 -----------------------------------------------
-
     /// and STL argorithm compatible predicate comparing a DriverAccess' impl name to a string
     struct CompareDriverAccessToName : public ::std::binary_function< DriverAccess, ::rtl::OUString, bool >
     {
@@ -310,9 +283,6 @@ OSDBCDriverManager::~OSDBCDriverManager()
 {
 }
 
-//---------------------------------------------------------------------
-//--- 24.08.01 11:15:32 -----------------------------------------------
-
 void OSDBCDriverManager::bootstrapDrivers()
 {
     Reference< XContentEnumerationAccess > xEnumAccess( m_aContext.getLegacyServiceFactory(), UNO_QUERY );
@@ -448,7 +418,7 @@ void OSDBCDriverManager::initializeDriverPrecedence()
     }
     catch (Exception&)
     {
-        OSL_ENSURE(sal_False, "OSDBCDriverManager::initializeDriverPrecedence: caught an exception while sorting the drivers!");
+        OSL_FAIL("OSDBCDriverManager::initializeDriverPrecedence: caught an exception while sorting the drivers!");
     }
 }
 
@@ -594,7 +564,7 @@ Reference< XInterface > SAL_CALL OSDBCDriverManager::Create( const Reference< XM
 //--------------------------------------------------------------------------
 ::rtl::OUString SAL_CALL OSDBCDriverManager::getImplementationName_static(  ) throw(RuntimeException)
 {
-    return ::rtl::OUString::createFromAscii("com.sun.star.comp.sdbc.OSDBCDriverManager");
+    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.sdbc.OSDBCDriverManager"));
 }
 
 //--------------------------------------------------------------------------
@@ -707,7 +677,7 @@ Reference< XDriver > OSDBCDriverManager::implGetDriverForURL(const ::rtl::OUStri
             aFind = ::std::find_if(
                 m_aDriversBS.begin(),		// begin of search range
                 m_aDriversBS.end(),			// end of search range
-                std::unary_compose< AcceptsURL, ExtractAfterLoad >( AcceptsURL( _rURL ), ExtractAfterLoad() )
+                o3tl::unary_compose< AcceptsURL, ExtractAfterLoad >( AcceptsURL( _rURL ), ExtractAfterLoad() )
                                             // compose two functors: extract the driver from the access, then ask the resulting driver for acceptance
             );
         } // if ( m_aDriversBS.find(sDriverFactoryName ) == m_aDriversBS.end() )
@@ -728,7 +698,7 @@ Reference< XDriver > OSDBCDriverManager::implGetDriverForURL(const ::rtl::OUStri
         DriverCollectionIterator aPos = ::std::find_if(
             m_aDriversRT.begin(),		// begin of search range
             m_aDriversRT.end(),			// end of search range
-            std::unary_compose< AcceptsURL, ExtractDriverFromCollectionElement >( AcceptsURL( _rURL ), ExtractDriverFromCollectionElement() )
+            o3tl::unary_compose< AcceptsURL, ExtractDriverFromCollectionElement >( AcceptsURL( _rURL ), ExtractDriverFromCollectionElement() )
                                         // compose two functors: extract the driver from the access, then ask the resulting driver for acceptance
         );
 
