@@ -46,7 +46,7 @@
 #include <map>
 
 #include <editeng/svxenum.hxx>
-#include <editeng/splwrap.hxx>      // Der Wrapper
+#include <editeng/splwrap.hxx>
 #include <editeng/edtdlg.hxx>      
 #include <editeng/eerdll.hxx>
 #include <editeng/editrids.hrc>
@@ -76,7 +76,7 @@ void SvxPrepareAutoCorrect( String &rOldText, String &rNewText )
     // rOldText: text to be replaced
     // rNewText: replacement text
 
-    xub_StrLen	nOldLen = rOldText.Len(),
+    xub_StrLen  nOldLen = rOldText.Len(),
                 nNewLen = rNewText.Len();
     if (nOldLen && nNewLen)
     {
@@ -88,8 +88,6 @@ void SvxPrepareAutoCorrect( String &rOldText, String &rNewText )
     }
 }
 
-// -----------------------------------------------------------------------
-
 #define SVX_LANG_NEED_CHECK			0
 #define SVX_LANG_OK					1
 #define SVX_LANG_MISSING			2
@@ -106,7 +104,7 @@ struct lt_LanguageType
     }
 };
 
-typedef std::map< LanguageType, USHORT, lt_LanguageType >   LangCheckState_map_t;
+typedef std::map< LanguageType, sal_uInt16, lt_LanguageType >   LangCheckState_map_t;
 
 static LangCheckState_map_t & GetLangCheckState()
 {
@@ -153,12 +151,12 @@ SvxSpellWrapper::~SvxSpellWrapper()
 }
 
 /*--------------------------------------------------------------------
- *	Beschreibung: Ctor, die Pruefreihenfolge wird festgelegt
+ *  Description: Constructor, the test sequence is determined
  *
- *  !bStart && !bOtherCntnt:	BODY_END,	BODY_START,	OTHER
- *  !bStart && bOtherCntnt:		OTHER,		BODY
- *  bStart && !bOtherCntnt:		BODY_END,	OTHER
- *  bStart && bOtherCntnt:		OTHER
+ *  !bStart && !bOtherCntnt:    BODY_END,   BODY_START, OTHER
+ *  !bStart && bOtherCntnt:     OTHER,      BODY
+ *  bStart && !bOtherCntnt:     BODY_END,   OTHER
+ *  bStart && bOtherCntnt:      OTHER
  *
  --------------------------------------------------------------------*/
 
@@ -167,20 +165,20 @@ SvxSpellWrapper::SvxSpellWrapper( Window* pWn,
     const sal_Bool bStart, const sal_Bool bIsAllRight,
     const sal_Bool bOther, const sal_Bool bRevAllow ) :
 
-    pWin		( pWn ),
-    xSpell		( xSpellChecker ),
-    bOtherCntnt	( bOther ),
-    bDialog		( sal_False ),
-    bHyphen		( sal_False ),
-    bAuto		( sal_False ),
-    bStartChk	( bOther ),
+    pWin        ( pWn ),
+    xSpell      ( xSpellChecker ),
+    bOtherCntnt ( bOther ),
+    bDialog     ( sal_False ),
+    bHyphen     ( sal_False ),
+    bAuto       ( sal_False ),
+    bStartChk   ( bOther ),
     bRevAllowed ( bRevAllow ),
     bAllRight   ( bIsAllRight )
 {
     Reference< beans::XPropertySet >  xProp( SvxGetLinguPropertySet() );
     sal_Bool bWrapReverse = xProp.is() ?
         *(sal_Bool*)xProp->getPropertyValue(
-            ::rtl::OUString::createFromAscii(UPN_IS_WRAP_REVERSE) ).getValue()
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(UPN_IS_WRAP_REVERSE)) ).getValue()
         : sal_False;
     bReverse = bRevAllow && bWrapReverse;
     bStartDone = bOther || ( !bReverse && bStart );
@@ -192,16 +190,16 @@ SvxSpellWrapper::SvxSpellWrapper( Window* pWn,
 SvxSpellWrapper::SvxSpellWrapper( Window* pWn,
         Reference< XHyphenator >  &xHyphenator,
         const sal_Bool bStart, const sal_Bool bOther ) :
-    pWin		( pWn ),
-    xHyph		( xHyphenator ),
-    bOtherCntnt	( bOther ),
-    bDialog		( sal_False ),
-    bHyphen		( sal_False ),
-    bAuto		( sal_False ),
-    bReverse	( sal_False ),
-    bStartDone	( bOther || ( !bReverse && bStart ) ),
-    bEndDone	( bReverse && bStart && !bOther ),
-    bStartChk	( bOther ),
+    pWin        ( pWn ),
+    xHyph       ( xHyphenator ),
+    bOtherCntnt ( bOther ),
+    bDialog     ( sal_False ),
+    bHyphen     ( sal_False ),
+    bAuto       ( sal_False ),
+    bReverse    ( sal_False ),
+    bStartDone  ( bOther || ( !bReverse && bStart ) ),
+    bEndDone    ( bReverse && bStart && !bOther ),
+    bStartChk   ( bOther ),
     bRevAllowed ( sal_False ),
     bAllRight   ( sal_True )
 {
@@ -263,15 +261,15 @@ sal_Int16 SvxSpellWrapper::CheckHyphLang(
 
 
 void SvxSpellWrapper::SpellStart( SvxSpellArea /*eSpell*/ )
-{	// Hier muessen die notwendigen Vorbereitungen fuer SpellContinue
-}	// im uebergebenen Bereich getroffen werden.
+{ // Here, the necessary preparations be made for SpellContinue in the 
+} // given area.
 
 // -----------------------------------------------------------------------
 
 
 sal_Bool SvxSpellWrapper::HasOtherCnt()
 {
-    return sal_False; // Gibt es ueberhaupt einen Sonderbereich?
+    return sal_False; // Is there a special area?
 }
 
 // -----------------------------------------------------------------------
@@ -279,14 +277,14 @@ sal_Bool SvxSpellWrapper::HasOtherCnt()
 
 sal_Bool SvxSpellWrapper::SpellMore()
 {
-    return sal_False; // Sollen weitere Dokumente geprueft werden?
+    return sal_False; // Should additional documents be examined?
 }
 
 // -----------------------------------------------------------------------
 
 
 void SvxSpellWrapper::SpellEnd()
-{	// Bereich ist abgeschlossen, ggf. Aufraeumen
+{   // Area is complete, tidy up if necessary 
 
     // display error for last language not found
     ShowLanguageErrors();
@@ -310,14 +308,14 @@ void SvxSpellWrapper::AutoCorrect( const String&, const String& )
 
 
 void SvxSpellWrapper::ScrollArea()
-{	// Scrollarea einstellen
+{   // Set Scroll area
 }
 
 // -----------------------------------------------------------------------
 
 
 void SvxSpellWrapper::ChangeWord( const String&, const sal_uInt16 )
-{	// Wort ersetzen
+{   // Insert Word
 }
 
 // -----------------------------------------------------------------------
@@ -325,7 +323,7 @@ void SvxSpellWrapper::ChangeWord( const String&, const sal_uInt16 )
 
 String SvxSpellWrapper::GetThesWord()
 {
-    // Welches Wort soll nachgeschlagen werden?
+    // What word should be looked up?
     return String();
 }
 
@@ -334,7 +332,7 @@ String SvxSpellWrapper::GetThesWord()
 
 void SvxSpellWrapper::ChangeThesWord( const String& )
 {
-    // Wort wg. Thesaurus ersetzen
+    // replace word due to Thesaurus.
 }
 
 // -----------------------------------------------------------------------
@@ -348,7 +346,7 @@ void SvxSpellWrapper::StartThesaurus( const String &rWord, sal_uInt16 nLanguage
         return;
     }
 
-    WAIT_ON();	// while looking up for initial word
+    WAIT_ON();  // while looking up for initial word
     EditAbstractDialogFactory* pFact = EditAbstractDialogFactory::Create();
     AbstractThesaurusDialog* pDlg = pFact->CreateThesaurusDialog( pWin, xThes, rWord, nLanguage );
     WAIT_OFF();
@@ -362,25 +360,25 @@ void SvxSpellWrapper::StartThesaurus( const String &rWord, sal_uInt16 nLanguage
 // -----------------------------------------------------------------------
 
 void SvxSpellWrapper::ReplaceAll( const String &, sal_Int16 )
-{	// Wort aus der Replace-Liste ersetzen
+{   // Replace Word from the the Replace list
 }
 
 // -----------------------------------------------------------------------
 
 
 void SvxSpellWrapper::SetLanguage( const sal_uInt16 )
-{	// Sprache aendern
+{   // Set Language
 }
 
 // -----------------------------------------------------------------------
 
 
 void SvxSpellWrapper::InsertHyphen( const sal_uInt16 )
-{	// Hyphen einfuegen bzw. loeschen
+{   // inserting and deleting Hyphae 
 }
 
 // -----------------------------------------------------------------------
-// Pruefung der Dokumentbereiche in der durch die Flags angegebenen Reihenfolge
+// Testing of the document areas in the order specified by the flags
 
 
 void SvxSpellWrapper::SpellDocument( )
@@ -398,8 +396,8 @@ void SvxSpellWrapper::SpellDocument( )
 
     if ( FindSpellError() )
     {
-        Reference< XSpellAlternatives >  	xAlt( GetLast(), UNO_QUERY );
-        Reference< XHyphenatedWord > 		xHyphWord( GetLast(), UNO_QUERY );
+        Reference< XSpellAlternatives >     xAlt( GetLast(), UNO_QUERY );
+        Reference< XHyphenatedWord >        xHyphWord( GetLast(), UNO_QUERY );
 
         Window *pOld = pWin;
         bDialog = sal_True;
@@ -420,7 +418,7 @@ void SvxSpellWrapper::SpellDocument( )
 }
 
 // -----------------------------------------------------------------------
-// Naechsten Bereich auswaehlen
+// Select the next area
 
 
 sal_Bool SvxSpellWrapper::SpellNext( )
@@ -428,30 +426,31 @@ sal_Bool SvxSpellWrapper::SpellNext( )
     Reference< beans::XPropertySet >  xProp( SvxGetLinguPropertySet() );
     sal_Bool bWrapReverse = xProp.is() ?
             *(sal_Bool*)xProp->getPropertyValue(
-                ::rtl::OUString::createFromAscii(UPN_IS_WRAP_REVERSE) ).getValue()
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(UPN_IS_WRAP_REVERSE)) ).getValue()
             : sal_False;
     sal_Bool bActRev = bRevAllowed && bWrapReverse;
 
-    // bActRev ist die Richtung nach dem Spellen, bReverse die am Anfang.
+    // bActRev is the direction after Spell checking, bReverse is the one 
+    // at the beginning.
     if( bActRev == bReverse )
-    {   						// Keine Richtungsaenderung, also ist
-        if( bStartChk )         // der gewuenschte Bereich ( bStartChk )
-            bStartDone = sal_True;  // vollstaendig abgearbeitet.
+    {                           // No change of direction, thus is the 
+        if( bStartChk )         // desired area ( bStartChk )
+            bStartDone = sal_True;  // completely processed.
         else
             bEndDone = sal_True;
     }
-    else if( bReverse == bStartChk ) // Bei einer Richtungsaenderung kann
-    { 						   // u.U. auch ein Bereich abgearbeitet sein.
-        if( bStartChk )        // Sollte der vordere Teil rueckwaerts gespellt
-            bEndDone = sal_True;   // werden und wir kehren unterwegs um, so ist
-        else				   // der hintere Teil abgearbeitet (und umgekehrt).
+    else if( bReverse == bStartChk ) //For a change of direction, an area can    
+    {                          // be processed during certain circumstances
+        if( bStartChk )        // If the firdt part is spell checked in backwards
+            bEndDone = sal_True;   // and this is reversed in the process, then 
+        else                   // then the end part is processed (and vice-versa).
             bStartDone = sal_True;
     }
 
     bReverse = bActRev;
-    if( bOtherCntnt && bStartDone && bEndDone ) // Dokument komplett geprueft?
+    if( bOtherCntnt && bStartDone && bEndDone ) // Document has been fully checked?
     {
-        if ( SpellMore() )  // ein weiteres Dokument pruefen?
+        if ( SpellMore() )  // spell check another document?
         {
             bOtherCntnt = sal_False;
             bStartDone = !bReverse;
@@ -474,15 +473,15 @@ sal_Bool SvxSpellWrapper::SpellNext( )
     {
         sal_Bool bIsSpellSpecial = xProp.is() ?
             *(sal_Bool*)xProp->getPropertyValue(
-                ::rtl::OUString::createFromAscii(UPN_IS_SPELL_SPECIAL) ).getValue()
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(UPN_IS_SPELL_SPECIAL)) ).getValue()
             : sal_False;
-        // Bodybereich erledigt, Frage nach Sonderbereich
+        // Body area done, ask for special area
         if( !IsHyphen() && bIsSpellSpecial && HasOtherCnt() )
         {
             SpellStart( SVX_SPELL_OTHER );
             bOtherCntnt = bGoOn = sal_True;
         }
-        else if ( SpellMore() )  // ein weiteres Dokument pruefen?
+        else if ( SpellMore() )  // check another document?
         {
             bOtherCntnt = sal_False;
             bStartDone = !bReverse;
@@ -493,24 +492,14 @@ sal_Bool SvxSpellWrapper::SpellNext( )
     }
     else
     {
-        // Ein BODY_Bereich erledigt, Frage nach dem anderen BODY_Bereich
+        // a BODY_area done, ask for the other BODY_area
         WAIT_OFF();
 
-// Sobald im Dialog das DontWrapAround gesetzt werden kann, kann der
-// folgende #ifdef-Zweig aktiviert werden ...
-#ifdef USED
-        sal_Bool bDontWrapAround = IsHyphen() ?
-            pSpell->GetOptions() & DONT_WRAPAROUND :
-            pSpell->GetHyphOptions() & HYPH_DONT_WRAPAROUND;
-        if( bDontWrapAround )
-#else
         sal_uInt16 nResId = bReverse ? RID_SVXQB_BW_CONTINUE : RID_SVXQB_CONTINUE;
         QueryBox aBox( pWin, EditResId( nResId ) );
         if ( aBox.Execute() != RET_YES )
-#endif
-
         {
-            // Verzicht auf den anderen Bereich, ggf. Frage nach Sonderbereich
+            // sacrifice the other area if necessary ask for special area 
             WAIT_ON();
             bStartDone = bEndDone = sal_True;
             return SpellNext();
@@ -576,7 +565,7 @@ sal_Bool SvxSpellWrapper::FindSpellError()
 {
     ShowLanguageErrors();
 
-     Reference< XInterface > 	xRef;
+     Reference< XInterface >    xRef;
 
     WAIT_ON();
     sal_Bool bSpell = sal_True;
@@ -589,8 +578,8 @@ sal_Bool SvxSpellWrapper::FindSpellError()
     {
         SpellContinue();
 
-        Reference< XSpellAlternatives >  	xAlt( GetLast(), UNO_QUERY );
-        Reference< XHyphenatedWord > 		xHyphWord( GetLast(), UNO_QUERY );
+        Reference< XSpellAlternatives >     xAlt( GetLast(), UNO_QUERY );
+        Reference< XHyphenatedWord >        xHyphWord( GetLast(), UNO_QUERY );
 
         if (xAlt.is())
         {
@@ -603,7 +592,7 @@ sal_Bool SvxSpellWrapper::FindSpellError()
                 // look up in ChangeAllList for misspelled word
                 Reference< XDictionary >    xChangeAllList(
                         SvxGetChangeAllList(), UNO_QUERY );
-                Reference< XDictionaryEntry > 	xEntry;
+                Reference< XDictionaryEntry >   xEntry;
                 if (xChangeAllList.is())
                     xEntry = xChangeAllList->getEntry( xAlt->getWord() );
 
