@@ -46,8 +46,8 @@
 #include <svx/svdview.hxx> // das
 #include <svx/svdundo.hxx> // Macro-Beispiel
 #include <svx/svdopath.hxx>
-#include "svdglob.hxx"  // Stringcache
-#include "svdstr.hrc"   // Objektname
+#include "svx/svdglob.hxx"  // Stringcache
+#include "svx/svdstr.hrc"   // Objektname
 #include <svx/xflclit.hxx>
 #include <svx/xlnclit.hxx>
 #include <svx/xlnwtit.hxx>
@@ -80,14 +80,14 @@ TYPEINIT1(SdrRectObj,SdrTextObj);
 SdrRectObj::SdrRectObj()
 :	mpXPoly(0L)
 {
-    bClosedObj=TRUE;
+    bClosedObj=sal_True;
 }
 
 SdrRectObj::SdrRectObj(const Rectangle& rRect)
 :	SdrTextObj(rRect),
     mpXPoly(NULL)
 {
-    bClosedObj=TRUE;
+    bClosedObj=sal_True;
 }
 
 SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind)
@@ -97,7 +97,7 @@ SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind)
     DBG_ASSERT(eTextKind==OBJ_TEXT || eTextKind==OBJ_TEXTEXT ||
                eTextKind==OBJ_OUTLINETEXT || eTextKind==OBJ_TITLETEXT,
                "SdrRectObj::SdrRectObj(SdrObjKind) ist nur fuer Textrahmen gedacht");
-    bClosedObj=TRUE;
+    bClosedObj=sal_True;
 }
 
 SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind, const Rectangle& rRect)
@@ -107,17 +107,17 @@ SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind, const Rectangle& rRect)
     DBG_ASSERT(eTextKind==OBJ_TEXT || eTextKind==OBJ_TEXTEXT ||
                eTextKind==OBJ_OUTLINETEXT || eTextKind==OBJ_TITLETEXT,
                "SdrRectObj::SdrRectObj(SdrObjKind,...) ist nur fuer Textrahmen gedacht");
-    bClosedObj=TRUE;
+    bClosedObj=sal_True;
 }
 
-SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind, const Rectangle& rNewRect, SvStream& rInput, const String& rBaseURL, USHORT eFormat)
+SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind, const Rectangle& rNewRect, SvStream& rInput, const String& rBaseURL, sal_uInt16 eFormat)
 :    SdrTextObj(eNewTextKind,rNewRect,rInput,rBaseURL,eFormat),
     mpXPoly(NULL)
 {
     DBG_ASSERT(eTextKind==OBJ_TEXT || eTextKind==OBJ_TEXTEXT ||
                eTextKind==OBJ_OUTLINETEXT || eTextKind==OBJ_TITLETEXT,
                "SdrRectObj::SdrRectObj(SdrObjKind,...) ist nur fuer Textrahmen gedacht");
-    bClosedObj=TRUE;
+    bClosedObj=sal_True;
 }
 
 SdrRectObj::~SdrRectObj()
@@ -186,22 +186,22 @@ void SdrRectObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
 {
     bool bNoTextFrame=!IsTextFrame();
     rInfo.bResizeFreeAllowed=bNoTextFrame || aGeo.nDrehWink%9000==0;
-    rInfo.bResizePropAllowed=TRUE;
-    rInfo.bRotateFreeAllowed=TRUE;
-    rInfo.bRotate90Allowed  =TRUE;
+    rInfo.bResizePropAllowed=sal_True;
+    rInfo.bRotateFreeAllowed=sal_True;
+    rInfo.bRotate90Allowed  =sal_True;
     rInfo.bMirrorFreeAllowed=bNoTextFrame;
     rInfo.bMirror45Allowed  =bNoTextFrame;
     rInfo.bMirror90Allowed  =bNoTextFrame;
 
     // allow transparence
-    rInfo.bTransparenceAllowed = TRUE;
+    rInfo.bTransparenceAllowed = sal_True;
 
     // gradient depends on fillstyle
     XFillStyle eFillStyle = ((XFillStyleItem&)(GetObjectItem(XATTR_FILLSTYLE))).GetValue();
     rInfo.bGradientAllowed = (eFillStyle == XFILL_GRADIENT);
 
     rInfo.bShearAllowed     =bNoTextFrame;
-    rInfo.bEdgeRadiusAllowed=TRUE;
+    rInfo.bEdgeRadiusAllowed=sal_True;
 
     bool bCanConv=!HasText() || ImpCanConvTextToCurve();
     if (bCanConv && !bNoTextFrame && !HasText()) {
@@ -212,10 +212,10 @@ void SdrRectObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
     rInfo.bCanConvToContour = (rInfo.bCanConvToPoly || LineGeometryUsageIsNecessary());
 }
 
-UINT16 SdrRectObj::GetObjIdentifier() const
+sal_uInt16 SdrRectObj::GetObjIdentifier() const
 {
-    if (IsTextFrame()) return UINT16(eTextKind);
-    else return UINT16(OBJ_RECT);
+    if (IsTextFrame()) return sal_uInt16(eTextKind);
+    else return sal_uInt16(OBJ_RECT);
 }
 
 void SdrRectObj::TakeUnrotatedSnapRect(Rectangle& rRect) const
@@ -244,7 +244,7 @@ void SdrRectObj::TakeObjNameSingul(XubString& rName) const
     }
     else
     {
-        USHORT nResId=STR_ObjNameSingulRECT;
+        sal_uInt16 nResId=STR_ObjNameSingulRECT;
         if (aGeo.nShearWink!=0) {
             nResId+=4;  // Parallelogramm oder Raute
             // Raute ist nicht, weil Shear die vertikalen Kanten verlaengert!
@@ -270,7 +270,7 @@ void SdrRectObj::TakeObjNamePlural(XubString& rName) const
 {
     if (IsTextFrame()) SdrTextObj::TakeObjNamePlural(rName);
     else {
-        USHORT nResId=STR_ObjNamePluralRECT;
+        sal_uInt16 nResId=STR_ObjNamePluralRECT;
         if (aGeo.nShearWink!=0) {
             nResId+=4;  // Parallelogramm oder Raute
         } else {
@@ -281,9 +281,9 @@ void SdrRectObj::TakeObjNamePlural(XubString& rName) const
     }
 }
 
-void SdrRectObj::operator=(const SdrObject& rObj)
+SdrRectObj* SdrRectObj::Clone() const
 {
-    SdrTextObj::operator=(rObj);
+    return CloneHelper< SdrRectObj >();
 }
 
 basegfx::B2DPolyPolygon SdrRectObj::TakeXorPoly() const
@@ -532,9 +532,9 @@ XubString SdrRectObj::GetMacroPopupComment(const SdrObjMacroHitRec& rRec) const
     return SdrTextObj::GetMacroPopupComment(rRec);
 }
 
-SdrGluePoint SdrRectObj::GetVertexGluePoint(USHORT nPosNum) const
+SdrGluePoint SdrRectObj::GetVertexGluePoint(sal_uInt16 nPosNum) const
 {
-    INT32 nWdt = ImpGetLineWdt(); // #i25616# ((XLineWidthItem&)(GetObjectItem(XATTR_LINEWIDTH))).GetValue();
+    sal_Int32 nWdt = ImpGetLineWdt(); // #i25616# ((XLineWidthItem&)(GetObjectItem(XATTR_LINEWIDTH))).GetValue();
     
     // #i25616#
     if(!LineIsOutsideGeometry())
@@ -554,13 +554,13 @@ SdrGluePoint SdrRectObj::GetVertexGluePoint(USHORT nPosNum) const
     if (aGeo.nDrehWink!=0) RotatePoint(aPt,aRect.TopLeft(),aGeo.nSin,aGeo.nCos);
     aPt-=GetSnapRect().Center();
     SdrGluePoint aGP(aPt);
-    aGP.SetPercent(FALSE);
+    aGP.SetPercent(sal_False);
     return aGP;
 }
 
-SdrGluePoint SdrRectObj::GetCornerGluePoint(USHORT nPosNum) const
+SdrGluePoint SdrRectObj::GetCornerGluePoint(sal_uInt16 nPosNum) const
 {
-    INT32 nWdt = ImpGetLineWdt(); // #i25616# ((XLineWidthItem&)(GetObjectItem(XATTR_LINEWIDTH))).GetValue();
+    sal_Int32 nWdt = ImpGetLineWdt(); // #i25616# ((XLineWidthItem&)(GetObjectItem(XATTR_LINEWIDTH))).GetValue();
     
     // #i25616#
     if(!LineIsOutsideGeometry())
@@ -580,11 +580,11 @@ SdrGluePoint SdrRectObj::GetCornerGluePoint(USHORT nPosNum) const
     if (aGeo.nDrehWink!=0) RotatePoint(aPt,aRect.TopLeft(),aGeo.nSin,aGeo.nCos);
     aPt-=GetSnapRect().Center();
     SdrGluePoint aGP(aPt);
-    aGP.SetPercent(FALSE);
+    aGP.SetPercent(sal_False);
     return aGP;
 }
 
-SdrObject* SdrRectObj::DoConvertToPolyObj(BOOL bBezier) const
+SdrObject* SdrRectObj::DoConvertToPolyObj(sal_Bool bBezier) const
 {
     XPolygon aXP(ImpCalcXPoly(aRect,GetEckenradius()));
     { // #40608# Nur Uebergangsweise bis zum neuen TakeContour()
